/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer.event;

import nl.cloudfarming.client.geoviewer.Geographical;
import nl.cloudfarming.eventbus.BaseGuiEventProducer;
import nl.cloudfarming.eventbus.GuiEventKey;
import nl.cloudfarming.eventbus.GuiEventProducer;

/**
 *
 * @author Timon Veenstra
 */
public enum GeoEvent implements GuiEventKey{

    /**
     * Requests focus for a {@link Geographical} object
     */
    REQUEST_FOCUS,
    /**
     * Sends a hint that a layer is no longer valid and should be discarded
     */
    DISCARD_LAYER,
    /**
     * Data of a layer have been changed
     */
    DATA_CHANGED_EVENT,
    /**
     * A new layer have been added
     */
    NEW_LAYER;    
    
    @Override
    public String getKey() {
        return toString();
    }
    
    /**
     * Static method to get a producer for this kind of events.
     * 
     * @return 
     */
    public static GuiEventProducer getProducer(){
        return new GeoEventProducer();
    }

    /**
     * The producer for this kind of events
     */
    public static class GeoEventProducer extends BaseGuiEventProducer {

        public GeoEventProducer() {
            super(GeoEvent.class);
        }
    }    
    
}
